@@ -97,7 +97,7 @@ ctx_config(struct gcli_ctx *ctx)
 }
 
 static bool
-should_init_dotgcli(gcli_ctx *ctx)
+should_init_dotgcli(struct gcli_ctx *ctx)
 {
 	struct gcli_dotgcli *dgcli = ctx_dotgcli(ctx);
 
@@ -115,7 +115,7 @@ find_dotgcli(void)
 
 	curr_dir_path = getcwd(NULL, 128);
 	if (!curr_dir_path)
-		err(1, "getcwd");
+		err(1, "gcli: getcwd");
 
 	/* Here we are trying to traverse upwards through the directory
 	 * tree, searching for a directory called .git.
@@ -123,7 +123,7 @@ find_dotgcli(void)
 	do {
 		curr_dir = opendir(curr_dir_path);
 		if (!curr_dir)
-			err(1, "opendir");
+			err(1, "gcli: opendir");
 
 		while ((ent = readdir(curr_dir))) {
 			if (strcmp(".", ent->d_name) == 0 || strcmp("..", ent->d_name) == 0)
@@ -154,7 +154,7 @@ find_dotgcli(void)
 
 			curr_dir_path = realpath(tmp, NULL);
 			if (!curr_dir_path)
-				err(1, "realpath at %s", tmp);
+				err(1, "gcli: realpath at %s", tmp);
 
 			free(tmp);
 
@@ -178,7 +178,7 @@ find_dotgcli(void)
 }
 
 static void
-init_local_config(gcli_ctx *ctx)
+init_local_config(struct gcli_ctx *ctx)
 {
 	if (!should_init_dotgcli(ctx)) {
 		return;
@@ -198,7 +198,7 @@ init_local_config(gcli_ctx *ctx)
 
 	int len = sn_mmap_file(path, &dgcli->mmap_pointer);
 	if (len < 0)
-		err(1, "Unable to open config file");
+		err(1, "gcli: unable to open config file");
 
 	dgcli->buffer = sn_sv_from_parts(dgcli->mmap_pointer, len);
 	dgcli->buffer = sn_sv_trim_front(dgcli->buffer);
@@ -210,7 +210,7 @@ init_local_config(gcli_ctx *ctx)
 		line = sn_sv_trim(line);
 
 		if (line.length == 0)
-			errx(1, "%s:%d: Unexpected end of line",
+			errx(1, "gcli: %s:%d: Unexpected end of line",
 			     path, curr_line);
 
 		// Comments
@@ -225,7 +225,7 @@ init_local_config(gcli_ctx *ctx)
 		key = sn_sv_trim(key);
 
 		if (key.length == 0)
-			errx(1, "%s:%d: empty key", path, curr_line);
+			errx(1, "gcli: %s:%d: empty key", path, curr_line);
 
 		line.data   += 1;
 		line.length -= 1;
@@ -291,7 +291,7 @@ parse_section_entry(struct config_parser *input,
 	sn_sv key = sn_sv_chop_until(&input->buffer, '=');
 
 	if (key.length == 0)
-		errx(1, "%s:%d: empty key", input->filename, input->line);
+		errx(1, "gcli: %s:%d: empty key", input->filename, input->line);
 
 	input->buffer.data   += 1;
 	input->buffer.length -= 1;
@@ -307,7 +307,7 @@ parse_section_title(struct config_parser *input)
 {
 	size_t len = 0;
 	if (input->buffer.length == 0)
-		errx(1, "%s:%d: unexpected end of input in section title",
+		errx(1, "gcli: %s:%d: unexpected end of input in section title",
 		     input->filename, input->line);
 
 
@@ -321,10 +321,10 @@ parse_section_title(struct config_parser *input)
 	skip_ws_and_comments(input);
 
 	if (input->buffer.length == 0)
-		errx(1, "%s:%d: unexpected end of input", input->filename, input->line);
+		errx(1, "gcli: %s:%d: unexpected end of input", input->filename, input->line);
 
 	if (input->buffer.data[0] != '{')
-		errx(1, "%s:%d: expected '{'", input->filename, input->line);
+		errx(1, "gcli: %s:%d: expected '{'", input->filename, input->line);
 
 	input->buffer.length -= 1;
 	input->buffer.data   += 1;
@@ -354,7 +354,7 @@ parse_config_section(struct gcli_config *cfg,
 	}
 
 	if (input->buffer.length == 0)
-		errx(1, "%s:%d: missing '}' before end of file",
+		errx(1, "gcli: %s:%d: missing '}' before end of file",
 		     input->filename, input->line);
 
 	input->buffer.length -= 1;
@@ -378,7 +378,7 @@ parse_config_file(struct gcli_config *cfg,
  * return 0. Otherwise return -1.
  */
 static struct gcli_config *
-ensure_config(gcli_ctx *ctx)
+ensure_config(struct gcli_ctx *ctx)
 {
 	struct gcli_config *cfg = ctx_config(ctx);
 	char *file_path = NULL;
@@ -405,13 +405,13 @@ ensure_config(gcli_ctx *ctx)
 	}
 
 	if (access(file_path, R_OK) < 0) {
-		warn("Cannot access config file at %s", file_path);
+		warn("gcli: cannot access config file at %s", file_path);
 		return cfg;
 	}
 
 	int len = sn_mmap_file(file_path, &cfg->mmap_pointer);
 	if (len < 0)
-		err(1, "Unable to open config file");
+		err(1, "gcli: unable to open config file");
 
 	cfg->buffer = sn_sv_from_parts(cfg->mmap_pointer, len);
 	cfg->buffer = sn_sv_trim_front(cfg->buffer);
@@ -490,7 +490,7 @@ gcli_config_init_ctx(struct gcli_ctx *ctx)
 }
 
 int
-gcli_config_parse_args(gcli_ctx *ctx, int *argc, char ***argv)
+gcli_config_parse_args(struct gcli_ctx *ctx, int *argc, char ***argv)
 {
 	/* These are the very first options passed to the gcli command
 	 * itself. It is the first ever getopt call we do to parse any
@@ -562,8 +562,10 @@ gcli_config_parse_args(gcli_ctx *ctx, int *argc, char ***argv)
 				cfg->override_forgetype = GCLI_FORGE_GITLAB;
 			} else if (strcmp(optarg, "gitea") == 0) {
 				cfg->override_forgetype = GCLI_FORGE_GITEA;
+			} else if (strcmp(optarg, "bugzilla") == 0) {
+				cfg->override_forgetype = GCLI_FORGE_BUGZILLA;
 			} else {
-				fprintf(stderr, "error: unknown forge type '%s'. "
+				fprintf(stderr, "gcli: error: unknown forge type '%s'. "
 				        "Have either github, gitlab or gitea.\n", optarg);
 				return EXIT_FAILURE;
 			}
@@ -604,7 +606,7 @@ find_section(struct gcli_config *cfg, char const *name)
 }
 
 struct gcli_config_entries const *
-gcli_config_get_section_entries(gcli_ctx *ctx, char const *section_name)
+gcli_config_get_section_entries(struct gcli_ctx *ctx, char const *section_name)
 {
 	struct gcli_config_section const *s;
 	struct gcli_config *cfg;
@@ -619,7 +621,8 @@ gcli_config_get_section_entries(gcli_ctx *ctx, char const *section_name)
 }
 
 sn_sv
-gcli_config_find_by_key(gcli_ctx *ctx, char const *section_name, char const *key)
+gcli_config_find_by_key(struct gcli_ctx *ctx, char const *section_name,
+                        char const *key)
 {
 	struct gcli_config_entry *entry;
 	struct gcli_config *cfg = ensure_config(ctx);
@@ -628,7 +631,7 @@ gcli_config_find_by_key(gcli_ctx *ctx, char const *section_name, char const *key
 		find_section(cfg, section_name);
 
 	if (!section) {
-		warnx("no config section with name '%s'", section_name);
+		warnx("gcli: no config section with name '%s'", section_name);
 		return SV_NULL;
 	}
 
@@ -641,7 +644,7 @@ gcli_config_find_by_key(gcli_ctx *ctx, char const *section_name, char const *key
 }
 
 static sn_sv
-gcli_local_config_find_by_key(gcli_ctx *ctx, char const *const key)
+gcli_local_config_find_by_key(struct gcli_ctx *ctx, char const *const key)
 {
 	struct gcli_dotgcli *lcfg = ctx_dotgcli(ctx);
 	struct gcli_config_entry *entry;
@@ -655,7 +658,7 @@ gcli_local_config_find_by_key(gcli_ctx *ctx, char const *const key)
 }
 
 char *
-gcli_config_get_editor(gcli_ctx *ctx)
+gcli_config_get_editor(struct gcli_ctx *ctx)
 {
 	ensure_config(ctx);
 
@@ -664,12 +667,13 @@ gcli_config_get_editor(gcli_ctx *ctx)
 
 static char const *const
 default_account_entry_names[] = {
-	[GCLI_FORGE_GITHUB] = "github-default-account",
-	[GCLI_FORGE_GITLAB] = "gitlab-default-account",
-	[GCLI_FORGE_GITEA]  = "gitea-default-account", };
+	[GCLI_FORGE_GITHUB]   = "github-default-account",
+	[GCLI_FORGE_GITLAB]   = "gitlab-default-account",
+	[GCLI_FORGE_GITEA]    = "gitea-default-account",
+	[GCLI_FORGE_BUGZILLA] = "bugzilla-default-account",};
 
 static char *
-get_default_account(gcli_ctx *ctx, gcli_forge_type ftype)
+get_default_account(struct gcli_ctx *ctx, gcli_forge_type ftype)
 {
 	char const *const defaultname = default_account_entry_names[ftype];
 	sn_sv act = gcli_config_find_by_key(ctx, "defaults", defaultname);
@@ -681,7 +685,7 @@ get_default_account(gcli_ctx *ctx, gcli_forge_type ftype)
 }
 
 static char *
-gcli_config_get_account(gcli_ctx *ctx)
+gcli_config_get_account(struct gcli_ctx *ctx)
 {
 	struct gcli_config *cfg = ctx_config(ctx);
 	gcli_forge_type ftype = gcli_config_get_forge_type(ctx);
@@ -697,13 +701,14 @@ gcli_config_get_account(gcli_ctx *ctx)
 }
 
 static char const *const default_urls[] = {
-	[GCLI_FORGE_GITHUB] = "https://api.github.com",
-	[GCLI_FORGE_GITLAB] = "https://gitlab.com/api/v4",
-	[GCLI_FORGE_GITEA]  = "https://codeberg.org/api/v1",
+	[GCLI_FORGE_GITHUB]   = "https://api.github.com",
+	[GCLI_FORGE_GITLAB]   = "https://gitlab.com/api/v4",
+	[GCLI_FORGE_GITEA]    = "https://codeberg.org/api/v1",
+	[GCLI_FORGE_BUGZILLA] = "https://bugs.freebsd.org/bugzilla",
 };
 
 char *
-gcli_config_get_apibase(gcli_ctx *ctx)
+gcli_config_get_apibase(struct gcli_ctx *ctx)
 {
 	char *acct = gcli_config_get_account(ctx);
 	char *url = NULL;
@@ -724,7 +729,7 @@ gcli_config_get_apibase(gcli_ctx *ctx)
 }
 
 char *
-gcli_config_get_account_name(gcli_ctx *ctx)
+gcli_config_get_account_name(struct gcli_ctx *ctx)
 {
 	char *account = gcli_config_get_account(ctx);
 	sn_sv actname = gcli_config_find_by_key(
@@ -736,7 +741,7 @@ gcli_config_get_account_name(gcli_ctx *ctx)
 }
 
 static char *
-get_account_token(gcli_ctx *ctx)
+get_account_token(struct gcli_ctx *ctx)
 {
 	char *account;
 	sn_sv token;
@@ -753,7 +758,7 @@ get_account_token(gcli_ctx *ctx)
 }
 
 char *
-gcli_config_get_token(gcli_ctx *ctx)
+gcli_config_get_token(struct gcli_ctx *ctx)
 {
 	ensure_config(ctx);
 
@@ -761,7 +766,7 @@ gcli_config_get_token(gcli_ctx *ctx)
 }
 
 sn_sv
-gcli_config_get_upstream(gcli_ctx *ctx)
+gcli_config_get_upstream(struct  gcli_ctx *ctx)
 {
 	init_local_config(ctx);
 
@@ -769,7 +774,7 @@ gcli_config_get_upstream(gcli_ctx *ctx)
 }
 
 bool
-gcli_config_pr_inhibit_delete_source_branch(gcli_ctx *ctx)
+gcli_config_pr_inhibit_delete_source_branch(struct gcli_ctx *ctx)
 {
 	sn_sv val;
 
@@ -781,7 +786,7 @@ gcli_config_pr_inhibit_delete_source_branch(gcli_ctx *ctx)
 }
 
 void
-gcli_config_get_upstream_parts(gcli_ctx *ctx, sn_sv *const owner,
+gcli_config_get_upstream_parts(struct gcli_ctx *ctx, sn_sv *const owner,
                                sn_sv *const repo)
 {
 	ensure_config(ctx);
@@ -791,7 +796,7 @@ gcli_config_get_upstream_parts(gcli_ctx *ctx, sn_sv *const owner,
 
 	/* Sanity check: did we actually reach the '/'? */
 	if (*upstream.data != '/')
-		errx(1, ".gcli has invalid upstream format. expected owner/repo");
+		errx(1, "gcli: .gcli has invalid upstream format. expected owner/repo");
 
 	upstream.data   += 1;
 	upstream.length -= 1;
@@ -799,7 +804,7 @@ gcli_config_get_upstream_parts(gcli_ctx *ctx, sn_sv *const owner,
 }
 
 sn_sv
-gcli_config_get_base(gcli_ctx *ctx)
+gcli_config_get_base(struct gcli_ctx *ctx)
 {
 	init_local_config(ctx);
 
@@ -807,7 +812,7 @@ gcli_config_get_base(gcli_ctx *ctx)
 }
 
 sn_sv
-gcli_config_get_override_default_account(gcli_ctx *ctx)
+gcli_config_get_override_default_account(struct gcli_ctx *ctx)
 {
 	struct gcli_config *cfg;
 
@@ -821,7 +826,7 @@ gcli_config_get_override_default_account(gcli_ctx *ctx)
 }
 
 static gcli_forge_type
-gcli_config_get_forge_type_internal(gcli_ctx *ctx)
+gcli_config_get_forge_type_internal(struct gcli_ctx *ctx)
 {
 	struct gcli_config *cfg = ctx_config(ctx);
 
@@ -839,7 +844,7 @@ gcli_config_get_forge_type_internal(gcli_ctx *ctx)
 		entry = gcli_config_find_by_key(ctx, section, "forge-type");
 		if (sn_sv_null(entry))
 			errx(1,
-			     "error: given default override account not found or "
+			     "gcli: error: given default override account not found or "
 			     "missing forge-type");
 	} else {
 		entry = gcli_local_config_find_by_key(ctx, "forge-type");
@@ -852,21 +857,23 @@ gcli_config_get_forge_type_internal(gcli_ctx *ctx)
 			return GCLI_FORGE_GITLAB;
 		else if (sn_sv_eq_to(entry, "gitea"))
 			return GCLI_FORGE_GITEA;
+		else if (sn_sv_eq_to(entry, "bugzilla"))
+			return GCLI_FORGE_BUGZILLA;
 		else
-			errx(1, "Unknown forge type "SV_FMT, SV_ARGS(entry));
+			errx(1, "gcli: unknown forge type "SV_FMT, SV_ARGS(entry));
 	}
 
 	/* As a last resort, try to infer from the git remote */
 	int const type = gcli_gitconfig_get_forgetype(ctx, cfg->override_remote);
 	if (type < 0)
-		errx(1, "error: cannot infer forge type. "
+		errx(1, "gcli: error: cannot infer forge type. "
 		     "use -t <forge-type> to overrride manually.");
 
 	return type;
 }
 
 gcli_forge_type
-gcli_config_get_forge_type(gcli_ctx *ctx)
+gcli_config_get_forge_type(struct gcli_ctx *ctx)
 {
 	gcli_forge_type const result = gcli_config_get_forge_type_internal(ctx);
 
@@ -876,12 +883,13 @@ gcli_config_get_forge_type(gcli_ctx *ctx)
 		static char const *const ftype_name[] = {
 			[GCLI_FORGE_GITHUB] = "GitHub",
 			[GCLI_FORGE_GITLAB] = "Gitlab",
-			[GCLI_FORGE_GITEA]  = "Gitea",
-			};
+			[GCLI_FORGE_GITEA] = "Gitea",
+			[GCLI_FORGE_BUGZILLA] = "Bugzilla",
+		};
 
 		if (!have_printed_forge_type) {
 			have_printed_forge_type = 1;
-			fprintf(stderr, "info: forge type is %s\n", ftype_name[result]);
+			fprintf(stderr, "gcli: info: forge type is %s\n", ftype_name[result]);
 		}
 	}
 
@@ -889,7 +897,7 @@ gcli_config_get_forge_type(gcli_ctx *ctx)
 }
 
 void
-gcli_config_get_repo(gcli_ctx *ctx, char const **const owner,
+gcli_config_get_repo(struct gcli_ctx *ctx, char const **const owner,
                      char const **const repo)
 {
 	sn_sv upstream = {0};
@@ -903,7 +911,7 @@ gcli_config_get_repo(gcli_ctx *ctx, char const **const owner,
 
 		if (forge >= 0) {
 			if ((int)(gcli_config_get_forge_type(ctx)) != forge)
-				errx(1, "error: forge types are inconsistent");
+				errx(1, "gcli: error: forge types are inconsistent");
 		}
 
 		return;
@@ -925,7 +933,7 @@ gcli_config_get_repo(gcli_ctx *ctx, char const **const owner,
 }
 
 int
-gcli_config_have_colours(gcli_ctx *ctx)
+gcli_config_have_colours(struct gcli_ctx *ctx)
 {
 	static int tested_tty = 0;
 	struct gcli_config *cfg;
