@@ -39,10 +39,12 @@
 
 #include <pdjson/pdjson.h>
 
+#include <time.h> /* for nanosleep */
+
 /* Workaround because gitlab doesn't give us an explicit field for
  * this. */
 static void
-gitlab_mrs_fixup(gcli_pull_list *const list)
+gitlab_mrs_fixup(struct gcli_pull_list *const list)
 {
 	for (size_t i = 0; i < list->pulls_size; ++i) {
 		list->pulls[i].merged = !strcmp(list->pulls[i].state, "merged");
@@ -50,12 +52,12 @@ gitlab_mrs_fixup(gcli_pull_list *const list)
 }
 
 int
-gitlab_fetch_mrs(gcli_ctx *ctx, char *url, int const max,
-                 gcli_pull_list *const list)
+gitlab_fetch_mrs(struct gcli_ctx *ctx, char *url, int const max,
+                 struct gcli_pull_list *const list)
 {
 	int rc = 0;
 
-	gcli_fetch_list_ctx fl = {
+	struct gcli_fetch_list_ctx fl = {
 		.listp = &list->pulls,
 		.sizep = &list->pulls_size,
 		.max = max,
@@ -72,9 +74,9 @@ gitlab_fetch_mrs(gcli_ctx *ctx, char *url, int const max,
 }
 
 int
-gitlab_get_mrs(gcli_ctx *ctx, char const *owner, char const *repo,
-               gcli_pull_fetch_details const *const details, int const max,
-               gcli_pull_list *const list)
+gitlab_get_mrs(struct gcli_ctx *ctx, char const *owner, char const *repo,
+               struct gcli_pull_fetch_details const *const details, int const max,
+               struct gcli_pull_list *const list)
 {
 	char *url = NULL;
 	char *e_owner = NULL;
@@ -125,7 +127,7 @@ gitlab_get_mrs(gcli_ctx *ctx, char const *owner, char const *repo,
 }
 
 static void
-gitlab_free_diff(gitlab_diff *diff)
+gitlab_free_diff(struct gitlab_diff *diff)
 {
 	free(diff->diff);
 	free(diff->old_path);
@@ -137,7 +139,7 @@ gitlab_free_diff(gitlab_diff *diff)
 }
 
 static void
-gitlab_free_diffs(gitlab_diff_list *list)
+gitlab_free_diffs(struct gitlab_diff_list *list)
 {
 	for (size_t i = 0; i < list->diffs_size; ++i) {
 		gitlab_free_diff(&list->diffs[i]);
@@ -148,17 +150,40 @@ gitlab_free_diffs(gitlab_diff_list *list)
 	list->diffs_size = 0;
 }
 
+static void
+gitlab_make_commit_diff(struct gcli_commit const *const commit,
+                        struct gitlab_diff const *const diff,
+                        char const *const prev_commit_sha, FILE *const out)
+{
+	fprintf(out, "diff --git a/%s b/%s\n", diff->old_path, diff->new_path);
+	if (diff->new_file) {
+		fprintf(out, "new file mode %s\n", diff->b_mode);
+		fprintf(out, "index 0000000..%s\n", commit->sha);
+	} else {
+		fprintf(out, "index %s..%s %s\n", prev_commit_sha, commit->sha,
+		        diff->b_mode);
+	}
+
+	fprintf(out, "--- %s%s\n",
+	        diff->new_file ? "" : "a/",
+	        diff->new_file ? "/dev/null" : diff->old_path);
+	fprintf(out, "+++ %s%s\n",
+	        diff->deleted_file ? "" : "b/",
+	        diff->deleted_file ? "/dev/null" : diff->new_path);
+	fputs(diff->diff, out);
+}
+
 static int
-gitlab_make_commit_patch(gcli_ctx *ctx, FILE *stream,
+gitlab_make_commit_patch(struct gcli_ctx *ctx, FILE *stream,
                          char const *const e_owner, char const *const e_repo,
                          char const *const prev_commit_sha,
-                         gcli_commit const *const commit)
+                         struct gcli_commit const *const commit)
 {
 	char *url;
 	int rc;
-	gitlab_diff_list list = {0};
+	struct gitlab_diff_list list = {0};
 
-	gcli_fetch_list_ctx fl = {
+	struct gcli_fetch_list_ctx fl = {
 		.listp = &list.diffs,
 		.sizep = &list.diffs_size,
 		.max = -1,
@@ -179,20 +204,11 @@ gitlab_make_commit_patch(gcli_ctx *ctx, FILE *stream,
 	fprintf(stream, "Subject: %s\n\n", commit->message);
 
 	for (size_t i = 0; i < list.diffs_size; ++i) {
-		gitlab_diff const *d = &list.diffs[i];
-		fprintf(stream,
-		        "diff --git a/%s b/%s\n"
-		        "index %s..%s %s\n"
-		        "--- a/%s\n"
-		        "+++ b/%s\n"
-		        "%s",
-		        d->old_path, d->new_path,
-		        prev_commit_sha, commit->sha, d->b_mode,
-		        d->old_path, d->new_path,
-		        d->diff);
+		gitlab_make_commit_diff(commit, &list.diffs[i],
+		                        prev_commit_sha, stream);
 	}
 
-	fprintf(stream, "--\n2.42.2\n\n");
+	fprintf(stream, "--\n2.42.2\n\n\n");
 
 	gitlab_free_diffs(&list);
 
@@ -202,13 +218,13 @@ err_fetch_diffs:
 }
 
 int
-gitlab_mr_get_patch(gcli_ctx *ctx, FILE *stream, char const *owner,
+gitlab_mr_get_patch(struct gcli_ctx *ctx, FILE *stream, char const *owner,
                     char const *reponame, gcli_id mr_number)
 {
 	int rc = 0;
 	char *e_owner, *e_repo;
-	gcli_pull pull = {0};
-	gcli_commit_list commits = {0};
+	struct gcli_pull pull = {0};
+	struct gcli_commit_list commits = {0};
 	char const *prev_commit_sha;
 	char *base_sha_short;
 
@@ -225,14 +241,14 @@ gitlab_mr_get_patch(gcli_ctx *ctx, FILE *stream, char const *owner,
 
 	base_sha_short = sn_strndup(pull.base_sha, 8);
 	prev_commit_sha = base_sha_short;
-	for (size_t i = 0; i < commits.commits_size; ++i) {
+	for (size_t i = commits.commits_size; i > 0; --i) {
 		rc = gitlab_make_commit_patch(ctx, stream, e_owner, e_repo,
 		                              prev_commit_sha,
-		                              &commits.commits[i]);
+		                              &commits.commits[i - 1]);
 		if (rc < 0)
 			goto err_make_commit_patch;
 
-		prev_commit_sha = commits.commits[i].sha;
+		prev_commit_sha = commits.commits[i - 1].sha;
 	}
 
 err_make_commit_patch:
@@ -248,7 +264,7 @@ err_get_pull:
 }
 
 int
-gitlab_mr_get_diff(gcli_ctx *ctx, FILE *stream, char const *owner,
+gitlab_mr_get_diff(struct gcli_ctx *ctx, FILE *stream, char const *owner,
                    char const *reponame, gcli_id mr_number)
 {
 	(void) stream;
@@ -260,10 +276,34 @@ gitlab_mr_get_diff(gcli_ctx *ctx, FILE *stream, char const *owner,
 }
 
 int
-gitlab_mr_merge(gcli_ctx *ctx, char const *owner, char const *repo,
+gitlab_mr_set_automerge(struct gcli_ctx *const ctx, char const *const owner,
+                        char const *const repo, gcli_id const mr_number)
+{
+	char *url, *e_owner, *e_repo;
+	int rc;
+
+	e_owner = gcli_urlencode(owner);
+	e_repo = gcli_urlencode(repo);
+
+	url = sn_asprintf("%s/projects/%s%%2F%s/merge_requests/%"PRIid"/merge"
+	                  "?merge_when_pipeline_succeeds=true",
+	                  gcli_get_apibase(ctx), e_owner, e_repo, mr_number);
+
+	free(e_owner);
+	free(e_repo);
+
+	rc = gcli_fetch_with_method(ctx, "PUT", url, NULL, NULL, NULL);
+
+	free(url);
+
+	return rc;
+}
+
+int
+gitlab_mr_merge(struct gcli_ctx *ctx, char const *owner, char const *repo,
                 gcli_id const mr_number, enum gcli_merge_flags const flags)
 {
-	gcli_fetch_buffer  buffer  = {0};
+	struct gcli_fetch_buffer buffer = {0};
 	char *url = NULL;
 	char *e_owner = NULL;
 	char *e_repo = NULL;
@@ -295,10 +335,10 @@ gitlab_mr_merge(gcli_ctx *ctx, char const *owner, char const *repo,
 }
 
 int
-gitlab_get_pull(gcli_ctx *ctx, char const *owner, char const *repo,
-                gcli_id const pr_number, gcli_pull *const out)
+gitlab_get_pull(struct gcli_ctx *ctx, char const *owner, char const *repo,
+                gcli_id const pr_number, struct gcli_pull *const out)
 {
-	gcli_fetch_buffer json_buffer = {0};
+	struct gcli_fetch_buffer json_buffer = {0};
 	char *url = NULL;
 	char *e_owner = NULL;
 	char *e_repo = NULL;
@@ -316,7 +356,7 @@ gitlab_get_pull(gcli_ctx *ctx, char const *owner, char const *repo,
 
 	rc = gcli_fetch(ctx, url, NULL, &json_buffer);
 	if (rc == 0) {
-		json_stream stream = {0};
+		struct json_stream stream = {0};
 		json_open_buffer(&stream, json_buffer.data, json_buffer.length);
 		parse_gitlab_mr(ctx, &stream, out);
 		json_close(&stream);
@@ -329,14 +369,14 @@ gitlab_get_pull(gcli_ctx *ctx, char const *owner, char const *repo,
 }
 
 int
-gitlab_get_pull_commits(gcli_ctx *ctx, char const *owner, char const *repo,
-                        gcli_id const pr_number, gcli_commit_list *const out)
+gitlab_get_pull_commits(struct gcli_ctx *ctx, char const *owner, char const *repo,
+                        gcli_id const pr_number, struct gcli_commit_list *const out)
 {
 	char *url = NULL;
 	char *e_owner = NULL;
 	char *e_repo = NULL;
 
-	gcli_fetch_list_ctx fl = {
+	struct gcli_fetch_list_ctx fl = {
 		.listp = &out->commits,
 		.sizep = &out->commits_size,
 		.max = -1,
@@ -356,221 +396,321 @@ gitlab_get_pull_commits(gcli_ctx *ctx, char const *owner, char const *repo,
 	return gcli_fetch_list(ctx, url, &fl);
 }
 
-int
-gitlab_mr_close(gcli_ctx *ctx, char const *owner, char const *repo,
-                gcli_id const pr_number)
+static int
+gitlab_mr_patch_state(struct gcli_ctx *const ctx, char const *const owner,
+                      char const *const repo, gcli_id const mr,
+                      char const *const new_state)
 {
-	char *url = NULL;
-	char *data = NULL;
-	char *e_owner = NULL;
-	char *e_repo = NULL;
+	char *url = NULL, *payload = NULL, *e_owner = NULL, *e_repo = NULL;
+	struct gcli_jsongen gen = {0};
 	int rc = 0;
 
+	/* Generate payload */
+	gcli_jsongen_init(&gen);
+	gcli_jsongen_begin_object(&gen);
+	{
+		gcli_jsongen_objmember(&gen, "state_event");
+		gcli_jsongen_string(&gen, new_state);
+	}
+	gcli_jsongen_end_object(&gen);
+
+	payload = gcli_jsongen_to_string(&gen);
+	gcli_jsongen_free(&gen);
+
+	/* Generate URL */
 	e_owner = gcli_urlencode(owner);
-	e_repo  = gcli_urlencode(repo);
+	e_repo = gcli_urlencode(repo);
 
 	url = sn_asprintf("%s/projects/%s%%2F%s/merge_requests/%"PRIid,
-	                  gcli_get_apibase(ctx), e_owner, e_repo, pr_number);
-	data = sn_asprintf("{ \"state_event\": \"close\"}");
+	                  gcli_get_apibase(ctx), e_owner, e_repo, mr);
 
-	rc = gcli_fetch_with_method(ctx, "PUT", url, data, NULL, NULL);
-
-	free(url);
 	free(e_owner);
 	free(e_repo);
-	free(data);
+
+	rc = gcli_fetch_with_method(ctx, "PUT", url, payload, NULL, NULL);
+
+	free(url);
+	free(payload);
 
 	return rc;
 }
 
 int
-gitlab_mr_reopen(gcli_ctx *ctx, char const *owner, char const *repo,
-                 gcli_id const pr_number)
+gitlab_mr_close(struct gcli_ctx *ctx, char const *owner, char const *repo,
+                gcli_id const mr)
 {
-	char *url = NULL;
-	char *data = NULL;
-	char *e_owner = NULL;
-	char *e_repo = NULL;
-	int rc = 0;
+	return gitlab_mr_patch_state(ctx, owner, repo, mr, "close");
+}
 
-	e_owner = gcli_urlencode(owner);
-	e_repo  = gcli_urlencode(repo);
+int
+gitlab_mr_reopen(struct gcli_ctx *ctx, char const *owner, char const *repo,
+                 gcli_id const mr)
+{
+	return gitlab_mr_patch_state(ctx, owner, repo, mr, "reopen");
+}
+
+/* This routine is a workaround for a Gitlab bug:
+ *
+ * https://gitlab.com/gitlab-org/gitlab/-/issues/353984
+ *
+ * This is a race condition because something in the creation of a merge request
+ * is being handled asynchronously. See the above link for more details.
+ *
+ * TL;DR: We need to wait until the »merge_status« field of the MR is set to
+ * »can_be_merged«. This is indicated by the mergable field becoming true. */
+static int
+gitlab_mr_wait_until_mergeable(struct gcli_ctx *ctx, char const *const e_owner,
+                               char const *const e_repo, gcli_id const mr_id)
+{
+	char *url;
+	int rc = 0;
+	struct timespec const ts = { .tv_sec = 1, .tv_nsec = 0 };
 
 	url = sn_asprintf("%s/projects/%s%%2F%s/merge_requests/%"PRIid,
-	                  gcli_get_apibase(ctx), e_owner, e_repo, pr_number);
-	data = sn_asprintf("{ \"state_event\": \"reopen\"}");
+	                  gcli_get_apibase(ctx), e_owner, e_repo, mr_id);
 
-	rc = gcli_fetch_with_method(ctx, "PUT", url, data, NULL, NULL);
+	for (;;) {
+		bool is_mergeable;
+		struct gcli_fetch_buffer buffer = {0};
+		struct json_stream stream = {0};
+		struct gcli_pull pull = {0};
+
+		rc = gcli_fetch(ctx, url, NULL, &buffer);
+		if (rc < 0)
+			break;
+
+		json_open_buffer(&stream, buffer.data, buffer.length);
+		rc = parse_gitlab_mr(ctx, &stream, &pull);
+		json_close(&stream);
+
+		/* FIXME: this doesn't quite cut it when the PR has no commits in it.
+		 * In that case this will turn into an infinite loop. */
+		is_mergeable = pull.mergeable;
+
+		gcli_pull_free(&pull);
+		free(buffer.data);
+
+		if (is_mergeable)
+			break;
+
+		/* sort of a hack: wait for a second until the next request goes out */
+		nanosleep(&ts, NULL);
+	}
 
-	free(e_owner);
-	free(e_repo);
 	free(url);
-	free(data);
 
 	return rc;
 }
 
 int
-gitlab_perform_submit_mr(gcli_ctx *ctx, gcli_submit_pull_options opts)
+gitlab_perform_submit_mr(struct gcli_ctx *ctx, struct gcli_submit_pull_options opts)
 {
 	/* Note: this doesn't really allow merging into repos with
 	 * different names. We need to figure out a way to make this
 	 * better for both github and gitlab. */
-	gcli_repo target = {0};
-	sn_sv target_branch = {0};
-	sn_sv source_owner = {0};
-	sn_sv source_branch = {0};
-	char *labels = NULL;
+	char *source_branch = NULL, *source_owner = NULL, *payload = NULL,
+	     *e_owner = NULL, *e_repo = NULL, *url = NULL;
+	char const *target_branch = NULL;
 	int rc = 0;
-
-	/* json escaped variants */
-	sn_sv e_source_branch, e_target_branch, e_title, e_body;
+	struct gcli_fetch_buffer buffer = {0};
+	struct gcli_jsongen gen = {0};
+	struct gcli_repo target = {0};
 
 	target_branch = opts.to;
-	source_branch = opts.from;
-	source_owner = sn_sv_chop_until(&source_branch, ':');
-	if (source_branch.length == 0)
+	source_owner = strdup(opts.from);
+	source_branch = strchr(source_owner, ':');
+	if (source_branch == NULL)
 		return gcli_error(ctx, "bad merge request source: expected 'owner:branch'");
 
-	source_branch.length -= 1;
-	source_branch.data += 1;
+	*source_branch++ = '\0';
 
 	/* Figure out the project id */
 	rc = gitlab_get_repo(ctx, opts.owner, opts.repo, &target);
 	if (rc < 0)
 		return rc;
 
-	/* escape things in the post payload */
-	e_source_branch = gcli_json_escape(source_branch);
-	e_target_branch = gcli_json_escape(target_branch);
-	e_title = gcli_json_escape(opts.title);
-	e_body = gcli_json_escape(opts.body);
+	/* generate payload */
+	gcli_jsongen_init(&gen);
+	gcli_jsongen_begin_object(&gen);
+	{
+		gcli_jsongen_objmember(&gen, "source_branch");
+		gcli_jsongen_string(&gen, source_branch);
 
-	/* Prepare the label list if needed */
-	if (opts.labels_size) {
-		char *joined_items = NULL;
+		gcli_jsongen_objmember(&gen, "target_branch");
+		gcli_jsongen_string(&gen, target_branch);
 
-		/* Join by "," */
-		joined_items = sn_join_with(
-			opts.labels, opts.labels_size, "\",\"");
+		gcli_jsongen_objmember(&gen, "title");
+		gcli_jsongen_string(&gen, opts.title);
 
-		/* Construct something we can shove into the payload below */
-		labels = sn_asprintf(", \"labels\": [\"%s\"]", joined_items);
-		free(joined_items);
+		/* description is optional and will be NULL if unset */
+		if (opts.body) {
+			gcli_jsongen_objmember(&gen, "description");
+			gcli_jsongen_string(&gen, opts.body);
+		}
+
+		gcli_jsongen_objmember(&gen, "target_project_id");
+		gcli_jsongen_number(&gen, target.id);
+
+		if (opts.labels_size) {
+			gcli_jsongen_objmember(&gen, "labels");
+
+			gcli_jsongen_begin_array(&gen);
+			for (size_t i = 0; i < opts.labels_size; ++i)
+				gcli_jsongen_string(&gen, opts.labels[i]);
+			gcli_jsongen_end_array(&gen);
+		}
 	}
+	gcli_jsongen_end_object(&gen);
+	payload = gcli_jsongen_to_string(&gen);
+	gcli_jsongen_free(&gen);
+	gcli_repo_free(&target);
 
-	/* prepare payload */
-	char *post_fields = sn_asprintf(
-		"{\"source_branch\":\""SV_FMT"\",\"target_branch\":\""SV_FMT"\", "
-		"\"title\": \""SV_FMT"\", \"description\": \""SV_FMT"\", "
-		"\"target_project_id\": %"PRIid" %s }",
-		SV_ARGS(e_source_branch),
-		SV_ARGS(e_target_branch),
-		SV_ARGS(e_title),
-		SV_ARGS(e_body),
-		target.id,
-		labels ? labels : "");
+	/* generate url */
+	e_owner = gcli_urlencode(source_owner);
+	e_repo = gcli_urlencode(opts.repo);
 
-	/* construct url. The thing below works as the string view is
-	 * malloced and also NUL-terminated */
-	char *e_owner = gcli_urlencode_sv(source_owner).data;
-	char *e_repo = gcli_urlencode(opts.repo);
-
-	char *url = sn_asprintf("%s/projects/%s%%2F%s/merge_requests",
-	                        gcli_get_apibase(ctx),
-	    e_owner, e_repo);
+	url = sn_asprintf("%s/projects/%s%%2F%s/merge_requests", gcli_get_apibase(ctx),
+	                  e_owner, e_repo);
 
 	/* perform request */
-	rc = gcli_fetch_with_method(ctx, "POST", url, post_fields, NULL, NULL);
+	rc = gcli_fetch_with_method(ctx, "POST", url, payload, NULL, &buffer);
+
+	/* if that succeeded and the user wants automerge, parse the result and
+	 * set the automerge flag */
+	if (rc == 0 && opts.automerge) {
+		struct json_stream stream = {0};
+		struct gcli_pull pull = {0};
+
+		json_open_buffer(&stream, buffer.data, buffer.length);
+		rc = parse_gitlab_mr(ctx, &stream, &pull);
+		json_close(&stream);
+
+		if (rc < 0)
+			goto out;
+
+		rc = gitlab_mr_wait_until_mergeable(ctx, e_owner, e_repo, pull.number);
+		if (rc < 0)
+			goto out;
+
+		rc = gitlab_mr_set_automerge(ctx, opts.owner, opts.repo, pull.number);
+
+	out:
+		gcli_pull_free(&pull);
+	}
 
 	/* cleanup */
-	free(e_source_branch.data);
-	free(e_target_branch.data);
-	free(e_title.data);
-	free(e_body.data);
 	free(e_owner);
 	free(e_repo);
-	free(labels);
-	free(post_fields);
+	free(buffer.data);
+	free(source_owner);
+	free(payload);
 	free(url);
 
 	return rc;
 }
 
+static int
+gitlab_mr_update_labels(struct gcli_ctx *ctx, char const *owner,
+                        char const *repo, gcli_id const mr,
+                        char const *const labels[], size_t const labels_size,
+                        char const *const update_action)
+{
+	char *url  = NULL, *payload = NULL, *list = NULL, *e_owner = NULL,
+	     *e_repo = NULL;
+	struct gcli_jsongen gen = {0};
+	int rc = 0;
+
+	/* Generate payload */
+	list = sn_join_with(labels, labels_size, ",");
+	gcli_jsongen_init(&gen);
+	gcli_jsongen_begin_object(&gen);
+	{
+		gcli_jsongen_objmember(&gen, update_action);
+		gcli_jsongen_string(&gen, list);
+	}
+	gcli_jsongen_end_object(&gen);
+	payload = gcli_jsongen_to_string(&gen);
+
+	gcli_jsongen_free(&gen);
+	free(list);
+
+	/* Generate URL */
+	e_owner = gcli_urlencode(owner);
+	e_repo = gcli_urlencode(repo);
+
+	url = sn_asprintf("%s/projects/%s%%2F%s/merge_requests/%"PRIid,
+	                  gcli_get_apibase(ctx), e_owner, e_repo, mr);
+
+	free(e_owner);
+	free(e_repo);
+
+	rc = gcli_fetch_with_method(ctx, "PUT", url, payload, NULL, NULL);
+
+	free(url);
+	free(payload);
+
+	return rc;
+}
+
 int
-gitlab_mr_add_labels(gcli_ctx *ctx, char const *owner, char const *repo,
+gitlab_mr_add_labels(struct gcli_ctx *ctx, char const *owner, char const *repo,
                      gcli_id const mr, char const *const labels[],
                      size_t const labels_size)
 {
-	char *url  = NULL;
-	char *data = NULL;
-	char *list = NULL;
-	int   rc   = 0;
-
-	url = sn_asprintf("%s/projects/%s%%2F%s/merge_requests/%"PRIid,
-	                  gcli_get_apibase(ctx), owner, repo, mr);
-
-	list = sn_join_with(labels, labels_size, ",");
-	data = sn_asprintf("{ \"add_labels\": \"%s\"}", list);
-
-	rc = gcli_fetch_with_method(ctx, "PUT", url, data, NULL, NULL);
-
-	free(url);
-	free(data);
-	free(list);
-
-	return rc;
+	return gitlab_mr_update_labels(ctx, owner, repo, mr, labels, labels_size,
+	                               "add_labels");
 }
 
 int
-gitlab_mr_remove_labels(gcli_ctx *ctx, char const *owner, char const *repo,
-                        gcli_id const mr, char const *const labels[],
-                        size_t const labels_size)
+gitlab_mr_remove_labels(struct gcli_ctx *ctx, char const *owner,
+                        char const *repo, gcli_id const mr,
+                        char const *const labels[], size_t const labels_size)
 {
-	char *url = NULL;
-	char *data = NULL;
-	char *list = NULL;
+	return gitlab_mr_update_labels(ctx, owner, repo, mr, labels, labels_size,
+	                               "remove_labels");
+}
+
+int
+gitlab_mr_set_milestone(struct gcli_ctx *ctx, char const *owner,
+                        char const *repo, gcli_id mr, gcli_id milestone_id)
+{
+	char *url = NULL, *payload = NULL, *e_owner = NULL, *e_repo = NULL;
+	struct gcli_jsongen gen = {0};
 	int rc = 0;
 
+	/* Generate Payload */
+	gcli_jsongen_init(&gen);
+	gcli_jsongen_begin_object(&gen);
+	{
+		gcli_jsongen_objmember(&gen, "milestone_id");
+		gcli_jsongen_id(&gen, milestone_id);
+	}
+	gcli_jsongen_end_object(&gen);
+
+	payload = gcli_jsongen_to_string(&gen);
+	gcli_jsongen_free(&gen);
+
+	/* Generate URL */
+	e_owner = gcli_urlencode(owner);
+	e_repo = gcli_urlencode(repo);
+
 	url = sn_asprintf("%s/projects/%s%%2F%s/merge_requests/%"PRIid,
-	                  gcli_get_apibase(ctx), owner, repo, mr);
+	                  gcli_get_apibase(ctx), e_owner, e_repo, mr);
 
-	list = sn_join_with(labels, labels_size, ",");
-	data = sn_asprintf("{ \"remove_labels\": \"%s\"}", list);
+	free(e_owner);
+	free(e_repo);
 
-	rc = gcli_fetch_with_method(ctx, "PUT", url, data, NULL, NULL);
+	rc = gcli_fetch_with_method(ctx, "PUT", url, payload, NULL, NULL);
 
 	free(url);
-	free(data);
-	free(list);
+	free(payload);
 
 	return rc;
 }
 
 int
-gitlab_mr_set_milestone(gcli_ctx *ctx, char const *owner, char const *repo,
-                        gcli_id mr, gcli_id milestone_id)
-{
-	char *url = NULL;
-	char *data = NULL;
-	int rc = 0;
-
-	url = sn_asprintf("%s/projects/%s%%2F%s/merge_requests/%"PRIid,
-	                  gcli_get_apibase(ctx), owner, repo, mr);
-
-	data = sn_asprintf("{ \"milestone_id\": \"%"PRIid"\"}", milestone_id);
-
-	rc = gcli_fetch_with_method(ctx, "PUT", url, data, NULL, NULL);
-
-	free(url);
-	free(data);
-
-	return rc;
-}
-
-int
-gitlab_mr_clear_milestone(gcli_ctx *ctx, char const *owner, char const *repo,
-                          gcli_id const mr)
+gitlab_mr_clear_milestone(struct gcli_ctx *ctx, char const *owner,
+                          char const *repo, gcli_id const mr)
 {
 	/* GitLab's REST API docs state:
 	 *
@@ -583,19 +723,20 @@ gitlab_mr_clear_milestone(gcli_ctx *ctx, char const *owner, char const *repo,
 /* Helper function to fetch the list of user ids that are reviewers
  * of a merge requests. */
 static int
-gitlab_mr_get_reviewers(gcli_ctx *ctx, char const *e_owner, char const *e_repo,
-                        gcli_id const mr, gitlab_reviewer_id_list *const out)
+gitlab_mr_get_reviewers(struct gcli_ctx *ctx, char const *e_owner,
+                        char const *e_repo, gcli_id const mr,
+                        struct gitlab_reviewer_id_list *const out)
 {
 	char *url;
 	int rc;
-	gcli_fetch_buffer json_buffer = {0};
+	struct gcli_fetch_buffer json_buffer = {0};
 
 	url = sn_asprintf("%s/projects/%s%%2F%s/merge_requests/%"PRIid,
 	                  gcli_get_apibase(ctx), e_owner, e_repo, mr);
 
 	rc = gcli_fetch(ctx, url, NULL, &json_buffer);
 	if (rc == 0) {
-		json_stream stream = {0};
+		struct json_stream stream = {0};
 		json_open_buffer(&stream, json_buffer.data, json_buffer.length);
 		parse_gitlab_reviewer_ids(ctx, &stream, out);
 		json_close(&stream);
@@ -608,7 +749,7 @@ gitlab_mr_get_reviewers(gcli_ctx *ctx, char const *e_owner, char const *e_repo,
 }
 
 static void
-gitlab_reviewer_list_free(gitlab_reviewer_id_list *const list)
+gitlab_reviewer_list_free(struct gitlab_reviewer_id_list *const list)
 {
 	free(list->reviewers);
 	list->reviewers = NULL;
@@ -616,13 +757,13 @@ gitlab_reviewer_list_free(gitlab_reviewer_id_list *const list)
 }
 
 int
-gitlab_mr_add_reviewer(gcli_ctx *ctx, char const *owner, char const *repo,
+gitlab_mr_add_reviewer(struct gcli_ctx *ctx, char const *owner, char const *repo,
                        gcli_id mr_number, char const *username)
 {
 	char *url, *e_owner, *e_repo, *payload;
 	int uid, rc = 0;
-	gitlab_reviewer_id_list list = {0};
-	gcli_jsongen gen = {0};
+	struct gitlab_reviewer_id_list list = {0};
+	struct gcli_jsongen gen = {0};
 
 	e_owner = gcli_urlencode(owner);
 	e_repo = gcli_urlencode(repo);
@@ -679,12 +820,12 @@ bail_get_reviewers:
 }
 
 int
-gitlab_mr_set_title(gcli_ctx *ctx, char const *const owner,
+gitlab_mr_set_title(struct gcli_ctx *ctx, char const *const owner,
                     char const *const repo, gcli_id const id,
                     char const *const new_title)
 {
 	char *url, *e_owner, *e_repo, *payload;
-	gcli_jsongen gen = {0};
+	struct gcli_jsongen gen = {0};
 	int rc = 0;
 
 	/* Generate url
